<cfscript>
	// ------------------------------------------------------------------------
	// Link verb for Fusebox 5, by Peter Boughton.
	//
	// description:
	// Accepts a resource and optional type and rel attributes, then creates 
	// a HTML link (or script) tag as appropriate.
	//
	// usage:
	// 1. add the lexicon declaration to your circuit file, eg:
	//    <circuit xmlns:cf="cf/">
	// 2. use the verb in a fuseaction:
	//    <cf:link resource="/javascript/myscript.js"/>
	//    <cf:link rel="home" type="text/html" resource="/"/>
	// 3. this will then generate the appropriate HTML and place it
	//    in the documents head tags using cfhtmlhead.
	//
	// ------------------------------------------------------------------------


	vA = fb_.verbInfo.Attributes;

	if (not structKeyExists(vA,"resource"))
	{
		fb_throw
		( "fusebox.badGrammar.requiredAttributeMissing"
		, "Required attribute is missing"
		, "The attribute 'resource' is required, for a 'link' verb in fuseaction #fb_.verbInfo.circuit#.#fb_.verbInfo.fuseaction#."
		);
	}
	if (not structKeyExists(vA,"type")){vA.type = 'AUTO';}
	if (not structKeyExists(vA,"rel")) {vA.rel = 'unknown';}

	if (fb_.verbInfo.executionMode is "start")
	{
		if (vA.Type EQ "AUTO")
		{
			vA.Type = ListLast(vA.Resource,'.');
		}
	}
	else
	{
		text = '';

		switch (UCase(vA.Type))
		{
			case 'JS':
				text = '<script type="text/javascript" src="#vA.Resource#"></script>';
			break;
			case 'CSS':
				text = '<link rel="stylesheet" type="text/css" href="#vA.Resource#"/>';
			break;
			default:
				text = '<link rel="#vA.Rel#" type="#vA.Type#" href="#vA.Resource#"/>';
			break;
		}
		fb_appendLine('<cfhtmlhead text="'& Replace(text,'"','""',"all") &'"/>');
	}
</cfscript>